@@ -119,8 +119,7 @@ function(x, nrow = 1, ncol = 1, eps = .Machine$double.eps, ...){
 	nnza <- ceiling((x@ia[nrow+1]-1)/2)+nrow
 	if(nrow!=x@dimension[2])
                 stop("Cannot convert an asymmetric matrix into `matrix.ssr' class")
-
-        if(sum(abs((t(as.matrix.csr(x))-as.matrix.csr(x))@ra))!=0)
+        if(!all.equal(t(as.matrix.csr(x))@ra, as.matrix.csr(x)@ra))
                 stop("Cannot convert an asymmetric matrix into `matrix.ssr' class")
 	z <- .Fortran(f_csrssr,
 		as.integer(nrow),
@@ -143,7 +142,7 @@ function(x, nrow = 1, ncol = 1, eps = .Machine$double.eps, ...){
 	nnza <- ceiling((x@ia[nrow+1]-1)/2)+nrow
 	if(nrow!=x@dimension[1])
                 stop("Cannot convert an asymmetric matrix into `matrix.ssc' class")
-        if(sum(abs((t(as.matrix.csr(x))-as.matrix.csr(x))@ra))!=0)
+        if(!all.equal(t(as.matrix.csr(x))@ra, as.matrix.csr(x)@ra))
                 stop("Cannot convert an asymmetric matrix into `matrix.ssc' class")
 	z <- .Fortran(f_cscssc,
 		as.integer(nrow),
@@ -1552,7 +1551,7 @@ setMethod("as.matrix.csr","matrix.csr.chol", function(x, nrow, ncol,
                                                       upper.tri=TRUE,
                                                       ...)
           {
-            returned.data <- .Fortran('f_chol2csr',
+            returned.data <- .Fortran('chol2csr',
                                       nrow=as.integer(x@nrow),
                                       nnzlindx=as.integer(x@nnzlindx),
                                       nsuper=as.integer(x@nsuper),
@@ -1723,7 +1722,7 @@ setAs("matrix.csr","matrix.diag.csr",function(from){
         new("matrix.diag.csr", ra = from@ra, ja = from@ja, ia = from@ia, dimension = from@dimension)
         })
 setMethod("diag","matrix.csr", function (x = 1, nrow, ncol){
-    if (is.matrix.csr(x) && nargs() == 1) {
+    if (is.matrix.csr(x) && missing(nrow) && missing(ncol)) {
         if ((m <- min(dim(x))) == 0)
             return(numeric(0))
         y <- rep(0,m)
@@ -2028,11 +2027,7 @@ setMethod("kronecker",signature(X="matrix",Y="matrix.csr"),  tmp)
 setMethod("kronecker",signature(X="matrix.csr",Y="matrix"),  tmp)
 rm(tmp)
 
-setGeneric("image", function(x, ...) standardGeneric("image"))
-#setGeneric("image")
-
-setMethod("image","matrix.csr",
-function(x,col=c("white","gray"),xlab="column",ylab="row", ...){
+.image.csr <- function(x,col=c("white","gray"),xlab="column",ylab="row", ...){
 	n <- x@dimension[1]
 	p <- x@dimension[2]
 	z <- matrix(0,n,p)
@@ -2043,7 +2038,8 @@ function(x,col=c("white","gray"),xlab="column",ylab="row", ...){
 	axis(1,pretty(1:p), ...)
 	axis(2,pretty(-(n:1)),labels=rev(pretty(1:n)), ...)
 	box()
-	})
+	}
+setMethod("image", c(x="matrix.csr"),.image.csr)
 #setMethod("summary","slm",summary.slm)
 #setMethod("summary","mslm",summary.mslm)
 #setMethod("coef","slm",coef.slm)
